﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;
using System.Drawing;
using System.Xml;
using System.Text;
using System.Windows.Forms;
using C1.Win.Olap;
using C1.C1Preview.Export;

namespace QuickStart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            // designer support
            InitializeComponent();

            // get data
            var da = new OleDbDataAdapter(Properties.Resources.SqlStatement, GetConnectionString());
            var dt = new DataTable("NorthWind Sales Data");
            da.Fill(dt);

            // assign data to C1OlapPage control
            _c1OlapPage.DataSource = dt;
            
            // show default view
            var olap = _c1OlapPage.OlapPanel.OlapEngine;
            olap.BeginUpdate();
            olap.RowFields.Add("Country");
            olap.ColumnFields.Add("Category");
            olap.ValueFields.Add("Sales");
            olap.EndUpdate();

            // load predefined olap views
            var doc = new XmlDocument();
            doc.LoadXml(Properties.Resources.OlapViews);

            // build menu with default olap views
            var menuView = new ToolStripDropDownButton("&View", Properties.Resources.Views_small);
            foreach (XmlNode nd in doc.SelectNodes("OlapViews/C1Olap"))
            {
                var tsi = menuView.DropDownItems.Add(nd.Attributes["id"].Value);
                tsi.Tag = nd;
            }
            menuView.DropDownItemClicked += MenuView_DropDownItemClicked;

            // add the new view menu to the toolstrip
            _c1OlapPage.ToolStrip.Items.Insert(3, menuView);

            //reload Export Options
            doc.LoadXml(Properties.Resources.OlapExportOptions);

            // build menu with Export Options
            var menuExport = new ToolStripDropDownButton("&Export", Properties.Resources.Views_small);
            foreach (XmlNode nd in doc.SelectNodes("OlapExport/Export"))
            {
                var tsi = menuExport.DropDownItems.Add(nd.Attributes["name"].Value);
                tsi.Tag = nd.Attributes["type"].Value;
            }
            menuExport.DropDownItemClicked += MenuExport_DropDownItemClicked;

            // add the new export menu to the toolstrip
            _c1OlapPage.ToolStrip.Items.Insert(11, menuExport);

        }

        // select a predefined Olap view
        void MenuView_DropDownItemClicked(object sender, ToolStripItemClickedEventArgs e)
        {
            var nd = e.ClickedItem.Tag as XmlNode;
            if (nd != null)
            {
                _c1OlapPage.OlapPanel.ViewDefinition = nd.OuterXml;
            }
        }

        // select Export option
        void MenuExport_DropDownItemClicked(object sender, ToolStripItemClickedEventArgs e)
        {
            string _exportOptn= e.ClickedItem.Tag as string;
            
            //Includes both Chart and Grid in the report
            _c1OlapPage.Document.ShowChart = true;
            _c1OlapPage.Document.ShowGrid = true;
            
            SaveFileDialog saveDialog = new SaveFileDialog();
            saveDialog.Title = "Save ";
            switch (_exportOptn)
            {
                case "RtfExporter" : 
                                     RtfExporter rtfExporter = new C1.C1Preview.Export.RtfExporter();
                                     rtfExporter.Paginated = true;
                                     rtfExporter.Document = _c1OlapPage.Document;
                                     rtfExporter.ShowOptions = false;
                                     saveDialog.Filter = "RTF File (*.rtf)|*.rtf";
                                     if (saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                                     {
                                         rtfExporter.Export(saveDialog.FileName);
                                     }
                                     break;
                case "XlsExporter" :
                                     XlsExporter xlsExporter = new C1.C1Preview.Export.XlsExporter();
                                     xlsExporter.Paginated = true;
                                     xlsExporter.Document = _c1OlapPage.Document;
                                     xlsExporter.ShowOptions = false;
                                     saveDialog.Filter = "XLS File (*.xls)|*.xls";
                                     if (saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                                     {
                                         xlsExporter.Export(saveDialog.FileName);
                                     }
                                     break;
                //case "HtmlExporter" :
                //                     HtmlExporter htmExporter = new C1.C1Preview.Export.HtmlExporter();
                //                     htmExporter.Paginated = true;
                //                     htmExporter.Document = _c1OlapPage.Document;
                //                     htmExporter.ShowOptions = false;
                //                     saveDialog.Filter = "Html File (*.htm)|*.htm";
                //                     if (saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                //                     {
                //                         htmExporter.Export(saveDialog.FileName);
                //                     }
                //                     break;
                case "EmfExporter" :
                                     EmfExporter emfExporter = new C1.C1Preview.Export.EmfExporter();
                                     emfExporter.Document = _c1OlapPage.Document;
                                     emfExporter.ShowOptions = false;
                                     saveDialog.Filter = "EMF File (*.emf)|*.emf";
                                     if (saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                                     {
                                         emfExporter.Export(saveDialog.FileName);
                                     }
                                     break;
                case "PdfExporter":
                                     PdfExporter pdfExporter = new C1.C1Preview.Export.PdfExporter();
                                     pdfExporter.Document = _c1OlapPage.Document;
                                     pdfExporter.ShowOptions = false;
                                     saveDialog.Filter = "Pdf File (*.pdf)|*.pdf";
                                     if (saveDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                                     {
                                         pdfExporter.Export(saveDialog.FileName);
                                     }
                                     break;
            }
        }

        // get standard nwind mdb connection string
        static string GetConnectionString()
        {
            string path = Environment.GetFolderPath(Environment.SpecialFolder.Personal) + @"\ComponentOne Samples\Common";
            string conn = @"provider=microsoft.jet.oledb.4.0;data source={0}\c1nwind.mdb;";
            return string.Format(conn, path);
        }
    }
}
